@@ -1,7 +1,7 @@
 """
 Type annotations for iotdeviceadvisor service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/literals/)
 
 Usage::
 
@@ -19,7 +19,13 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("StatusType", "SuiteRunStatusType", "ServiceName")
+__all__ = (
+    "StatusType",
+    "SuiteRunStatusType",
+    "IoTDeviceAdvisorServiceName",
+    "ServiceName",
+    "ResourceServiceName",
+)
 
 
 StatusType = Literal[
@@ -44,6 +50,7 @@ SuiteRunStatusType = Literal[
     "STOPPED",
     "STOPPING",
 ]
+IoTDeviceAdvisorServiceName = Literal["iotdeviceadvisor"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -75,6 +82,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -161,6 +169,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -197,6 +206,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -345,3 +355,15 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
