@@ -1,7 +1,7 @@
 """
 Type annotations for iotdeviceadvisor service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/type_defs/)
 
 Usage::
 
@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Mapping, Sequence
 
+from typing_extensions import NotRequired
+
 from .literals import StatusType, SuiteRunStatusType
 
 if sys.version_info >= (3, 9):
